# -*- coding: utf-8 -*-
"""
This module shows you how to perform color space conversions. Please see the
chart on www.brucelindbloom.com/Math.html for an illustration of the conversions
you may perform.
"""

# Does some sys.path manipulation so we can run examples in-place.
# noinspection PyUnresolvedReferences
import example_config  # noqa

from colormath2.color_conversions import convert_color
from colormath2.color_objects import (
    LabColor,
    LCHabColor,
    SpectralColor,
    sRGBColor,
    XYZColor,
    LCHuvColor,
    IPTColor,
)


def example_lab_to_xyz():
    """
    This function shows a simple conversion of an Lab color to an XYZ color.
    """

    print("=== Simple Example: Lab->XYZ ===")
    # Instantiate an Lab color object with the given values.
    lab = LabColor(0.903, 16.296, -2.22)
    # Show a string representation.
    print(lab)
    # Convert to XYZ.
    xyz = convert_color(lab, XYZColor)
    print(xyz)
    print("=== End Example ===\n")


def example_lchab_to_lchuv():
    """
    This function shows very complex chain of conversions in action.

    LCHab to LCHuv involves four different calculations, making this the
    conversion requiring the most steps.
    """

    print("=== Complex Example: LCHab->LCHuv ===")
    # Instantiate an LCHab color object with the given values.
    lchab = LCHabColor(0.903, 16.447, 352.252)
    # Show a string representation.
    print(lchab)
    # Convert to LCHuv.
    lchuv = convert_color(lchab, LCHuvColor)
    print(lchuv)
    print("=== End Example ===\n")


def example_lab_to_rgb():
    """
    Conversions to RGB are a little more complex mathematically. There are also
    several kinds of RGB color spaces. When converting from a device-independent
    color space to RGB, sRGB is assumed unless otherwise specified with the
    target_rgb keyword arg.
    """

    print("=== RGB Example: Lab->RGB ===")
    # Instantiate an Lab color object with the given values.
    lab = LabColor(0.903, 16.296, -2.217)
    # Show a string representation.
    print(lab)
    # Convert to XYZ.
    rgb = convert_color(lab, sRGBColor)
    print(rgb)
    print("=== End Example ===\n")


def example_rgb_to_xyz():
    """
    The reverse is similar.
    """

    print("=== RGB Example: RGB->XYZ ===")
    # Instantiate an Lab color object with the given values.
    rgb = sRGBColor(120, 130, 140)
    # Show a string representation.
    print(rgb)
    # Convert RGB to XYZ using a D50 illuminant.
    xyz = convert_color(rgb, XYZColor, target_illuminant="D50")
    print(xyz)
    print("=== End Example ===\n")


def example_spectral_to_xyz():
    """
    Instantiate an Lab color object with the given values. Note that the
    spectral range can run from 340nm to 830nm. Any omitted values assume a
    value of 0.0, which is more or less ignored. For the distribution below,
    we are providing an example reading from an X-Rite i1 Pro, which only
    measures between 380nm and 730nm.
    """

    print("=== Example: Spectral->XYZ ===")
    spc = SpectralColor(
        observer="2",
        illuminant="d50",
        spec_380nm=0.0600,
        spec_390nm=0.0600,
        spec_400nm=0.0641,
        spec_410nm=0.0654,
        spec_420nm=0.0645,
        spec_430nm=0.0605,
        spec_440nm=0.0562,
        spec_450nm=0.0543,
        spec_460nm=0.0537,
        spec_470nm=0.0541,
        spec_480nm=0.0559,
        spec_490nm=0.0603,
        spec_500nm=0.0651,
        spec_510nm=0.0680,
        spec_520nm=0.0705,
        spec_530nm=0.0736,
        spec_540nm=0.0772,
        spec_550nm=0.0809,
        spec_560nm=0.0870,
        spec_570nm=0.0990,
        spec_580nm=0.1128,
        spec_590nm=0.1251,
        spec_600nm=0.1360,
        spec_610nm=0.1439,
        spec_620nm=0.1511,
        spec_630nm=0.1590,
        spec_640nm=0.1688,
        spec_650nm=0.1828,
        spec_660nm=0.1996,
        spec_670nm=0.2187,
        spec_680nm=0.2397,
        spec_690nm=0.2618,
        spec_700nm=0.2852,
        spec_710nm=0.2500,
        spec_720nm=0.2400,
        spec_730nm=0.2300,
    )
    xyz = convert_color(spc, XYZColor)
    print(xyz)
    print("=== End Example ===\n")


def example_lab_to_ipt():
    """
    This function shows a simple conversion of an XYZ color to an IPT color.
    """

    print("=== Simple Example: XYZ->IPT ===")
    # Instantiate an XYZ color object with the given values.
    xyz = XYZColor(0.5, 0.5, 0.5, illuminant="d65")
    # Show a string representation.
    print(xyz)
    # Convert to IPT.
    ipt = convert_color(xyz, IPTColor)
    print(ipt)
    print("=== End Example ===\n")


# Feel free to comment/un-comment examples as you please.
example_lab_to_xyz()
example_lchab_to_lchuv()
example_lab_to_rgb()
example_spectral_to_xyz()
example_rgb_to_xyz()
example_lab_to_ipt()



# -*- coding: utf-8 -*-
"""
This module shows you how to perform various kinds of density calculations.
"""

# Does some sys.path manipulation so we can run examples in-place.
# noinspection PyUnresolvedReferences
import example_config  # noqa

from colormath2.color_objects import SpectralColor
from colormath2.density_standards import ANSI_STATUS_T_RED, ISO_VISUAL

EXAMPLE_COLOR = SpectralColor(
    observer=2,
    illuminant="d50",
    spec_380nm=0.0600,
    spec_390nm=0.0600,
    spec_400nm=0.0641,
    spec_410nm=0.0654,
    spec_420nm=0.0645,
    spec_430nm=0.0605,
    spec_440nm=0.0562,
    spec_450nm=0.0543,
    spec_460nm=0.0537,
    spec_470nm=0.0541,
    spec_480nm=0.0559,
    spec_490nm=0.0603,
    spec_500nm=0.0651,
    spec_510nm=0.0680,
    spec_520nm=0.0705,
    spec_530nm=0.0736,
    spec_540nm=0.0772,
    spec_550nm=0.0809,
    spec_560nm=0.0870,
    spec_570nm=0.0990,
    spec_580nm=0.1128,
    spec_590nm=0.1251,
    spec_600nm=0.1360,
    spec_610nm=0.1439,
    spec_620nm=0.1511,
    spec_630nm=0.1590,
    spec_640nm=0.1688,
    spec_650nm=0.1828,
    spec_660nm=0.1996,
    spec_670nm=0.2187,
    spec_680nm=0.2397,
    spec_690nm=0.2618,
    spec_700nm=0.2852,
    spec_710nm=0.2500,
    spec_720nm=0.2400,
    spec_730nm=0.2300,
)


def example_auto_status_t_density():
    print("=== Example: Automatic Status T Density ===")
    # If no arguments are provided to calc_density(), ANSI Status T density is
    # assumed. The correct RGB "filter" is automatically selected for you.
    print("Density: %f" % EXAMPLE_COLOR.calc_density())
    print("=== End Example ===\n")


def example_manual_status_t_density():
    print("=== Example: Manual Status T Density ===")
    # Here we are specifically requesting the value of the red band via the
    # ANSI Status T spec.
    print(
        "Density: %f (Red)"
        % EXAMPLE_COLOR.calc_density(density_standard=ANSI_STATUS_T_RED)
    )
    print("=== End Example ===\n")


def example_visual_density():
    print("=== Example: Visual Density ===")
    # Here we pass the ISO Visual spectral standard.
    print("Density: %f" % EXAMPLE_COLOR.calc_density(density_standard=ISO_VISUAL))
    print("=== End Example ===\n")


# Feel free to comment/un-comment examples as you please.
example_auto_status_t_density()
example_manual_status_t_density()
example_visual_density()



# -*- coding: utf-8 -*-
from colormath2.color_appearance_models import CIECAM02
from colormath2.color_objects import XYZColor


# Color stimulus
color = XYZColor(19.01, 20, 21.78)

# Illuminant
illuminant_d65 = XYZColor(95.05, 100, 108.88)

# Background relative luminance
y_b_dark = 10
y_b_light = 100

# Adapting luminance
l_a = 328.31

# Surround condition assumed to be average (see CIECAM02 documentation for values)
c = 0.69
n_c = 1
f = 1

model_a = CIECAM02(
    color.xyz_x,
    color.xyz_y,
    color.xyz_z,
    illuminant_d65.xyz_x,
    illuminant_d65.xyz_y,
    illuminant_d65.xyz_z,
    y_b_dark,
    l_a,
    c,
    n_c,
    f,
)
model_b = CIECAM02(
    color.xyz_x,
    color.xyz_y,
    color.xyz_z,
    illuminant_d65.xyz_x,
    illuminant_d65.xyz_y,
    illuminant_d65.xyz_z,
    y_b_light,
    l_a,
    c,
    n_c,
    f,
)

print("== CIECAM02 Predictions ==")

print("Observed under CIE illuminant D65")
print(
    "Lightness {:.2f}, saturation {:.2f}, hue {:.2f}".format(
        model_a.lightness, model_a.saturation, model_a.hue_angle
    )
)
print("Observed under CIE illuminant A")
print(
    "Lightness {:.2f}, saturation {:.2f}, hue {:.2f}".format(
        model_b.lightness, model_b.saturation, model_b.hue_angle
    )
)



# -*- coding: utf-8 -*-
"""
For a massive matrix of colors and color labels you can download
the follow two files

# http://lyst-classifiers.s3.amazonaws.com/color/lab-colors.pk
# http://lyst-classifiers.s3.amazonaws.com/color/lab-matrix.pk

lab-colors is a cPickled list of color names and lab-matrix is a
cPickled (n,3) numpy array LAB values such that row q maps to
index q in the lab color list
"""

import sys
import csv
import bz2

import numpy as np

# Does some sys.path manipulation so we can run examples in-place.
# noinspection PyUnresolvedReferences
import example_config  # noqa

from colormath2.color_diff_matrix import delta_e_cie2000
from colormath2.color_objects import LabColor


# load list of 1000 random colors from the XKCD color chart
if sys.version_info >= (3, 0):
    reader = csv.DictReader(bz2.open("lab_matrix.csv.bz2", mode="rt"))
    lab_matrix = np.array([list(map(float, row.values())) for row in reader])
else:
    reader = csv.DictReader(bz2.BZ2File("lab_matrix.csv.bz2"))
    lab_matrix = np.array([map(float, row.values()) for row in reader])

color = LabColor(lab_l=69.34, lab_a=-0.88, lab_b=-52.57)
lab_color_vector = np.array([color.lab_l, color.lab_a, color.lab_b])
delta = delta_e_cie2000(lab_color_vector, lab_matrix)

print("%s is closest to %s" % (color, lab_matrix[np.argmin(delta)]))



# -*- coding: utf-8 -*-
"""
This module shows some examples of Delta E calculations of varying types.
"""

# Does some sys.path manipulation so we can run examples in-place.
# noinspection PyUnresolvedReferences
import example_config  # noqa

from colormath2.color_objects import LabColor
from colormath2.color_diff import (
    delta_e_cie1976,
    delta_e_cie1994,
    delta_e_cie2000,
    delta_e_cmc,
)

# Reference color.
color1 = LabColor(lab_l=0.9, lab_a=16.3, lab_b=-2.22)
# Color to be compared to the reference.
color2 = LabColor(lab_l=0.7, lab_a=14.2, lab_b=-1.80)

print("== Delta E Colors ==")
print(" COLOR1: %s" % color1)
print(" COLOR2: %s" % color2)
print("== Results ==")
print(" CIE1976: %.3f" % delta_e_cie1976(color1, color2))
print(" CIE1994: %.3f (Graphic Arts)" % delta_e_cie1994(color1, color2))
# Different values for textiles.
print(
    " CIE1994: %.3f (Textiles)"
    % delta_e_cie1994(color1, color2, K_1=0.048, K_2=0.014, K_L=2)
)
print(" CIE2000: %.3f" % delta_e_cie2000(color1, color2))
# Typically used for acceptability.
print("     CMC: %.3f (2:1)" % delta_e_cmc(color1, color2, pl=2, pc=1))
# Typically used to more closely model human perception.
print("     CMC: %.3f (1:1)" % delta_e_cmc(color1, color2, pl=1, pc=1))



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import colormath2

from setuptools import setup

LONG_DESCRIPTION = open("README.rst").read()

CLASSIFIERS = [
    "Development Status :: 5 - Production/Stable",
    "Intended Audience :: Developers",
    "License :: OSI Approved :: BSD License",
    "Natural Language :: English",
    "Operating System :: OS Independent",
    "Programming Language :: Python",
    "Topic :: Scientific/Engineering :: Mathematics",
    "Topic :: Software Development :: Libraries :: Python Modules",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
    "Programming Language :: Python :: 3.10",
    "Programming Language :: Python :: 3.11",
    "Programming Language :: Python :: 3.12",
    "Programming Language :: Python :: 3.13",
]

KEYWORDS = "color math conversions"

setup(
    name="colormath2",
    version=colormath2.VERSION,
    description="Color math and conversion library.",
    long_description=LONG_DESCRIPTION,
    long_description_content_type="text/x-rst",
    author="Gregory Taylor",
    author_email="gtaylor@gc-taylor.com",
    maintainer="Benson Muite",
    url="https://github.com/bkmgit/python-colormath2",
    download_url="http://pypi.python.org/pypi/colormath2/",
    packages=["colormath2"],
    platforms=["Platform Independent"],
    license="BSD-3-Clause",
    classifiers=CLASSIFIERS,
    keywords=KEYWORDS,
    install_requires=["numpy", "networkx>=2.0"],
    extras_require={"development": ["black", "flake8", "nose2", "pre-commit", "sphinx"]},
)
